%{?scl:%scl_package jctools}
%{!?scl:%global pkg_name %{name}}

%global baserelease 3

%global namedreltag %nil
%global namedversion %{version}%{?namedreltag}

Name:          %{?scl_prefix}jctools
Version:       2.1.2
Release:       1.%{baserelease}%{?dist}
Summary:       Java Concurrency Tools for the JVM
License:       ASL 2.0
URL:           http://jctools.github.io/JCTools/
Source0:       https://github.com/JCTools/JCTools/archive/v%{namedversion}/%{pkg_name}-%{namedversion}.tar.gz

# See: https://bugzilla.redhat.com/show_bug.cgi?id=1589113
Source11:       javaparser.tar.gz

BuildRequires:  %{?scl_prefix_maven}maven-local
BuildRequires:  %{?scl_prefix}mvn(com.google.guava:guava-testlib:20.0)
BuildRequires:  %{?scl_prefix_maven}mvn(junit:junit)
BuildRequires:  %{?scl_prefix_maven}mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  %{?scl_prefix_maven}mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  %{?scl_prefix_maven}mvn(org.hamcrest:hamcrest-all)
BuildRequires:  %{?scl_prefix}mvn(org.ow2.asm:asm-util:7.0)

BuildArch:     noarch

%description
This project aims to offer some concurrent data structures
currently missing from the JDK:

° SPSC/MPSC/SPMC/MPMC Bounded lock free queues
° SPSC/MPSC Unbounded lock free queues
° Alternative interfaces for queues
° Offheap concurrent ring buffer for ITC/IPC purposes
° Single Writer Map/Set implementations
° Low contention stats counters
° Executor

%package channels
Summary:       JCTools Channel implementations

%description channels
Channel implementations for the
Java Concurrency Tools Library.

%package experimental
Summary:       JCTools Experimental implementations

%description experimental
Experimental implementations for the
Java Concurrency Tools Library.

%package javadoc
Summary:       Javadoc for %{pkg_name}

%description javadoc
This package contains javadoc for %{pkg_name}.

%package parent
Summary:       JCTools Parent POM

%description parent
JCTools Parent POM.

%prep
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
%setup -q -n JCTools-%{namedversion}
# Cleanup
find . -name '*.class' -print -delete
find . -name '*.jar' -print -delete

%pom_xpath_set pom:project/pom:version %{namedversion}
%pom_xpath_set -r pom:parent/pom:version %{namedversion} %{pkg_name}-{build,core,channels,experimental}

# Remove plugins unnecessary for RPM builds
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :coveralls-maven-plugin
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :maven-source-plugin %{pkg_name}-core
%pom_remove_plugin :maven-javadoc-plugin %{pkg_name}-core

# Unavailable deps
%pom_disable_module %{pkg_name}-benchmarks
%pom_disable_module %{pkg_name}-concurrency-test

# Modern asm deps
%pom_change_dep ":asm-all" ":asm-util" jctools-{channels,experimental}

# Add OSGi support
for mod in core experimental; do
 %pom_xpath_set "pom:project/pom:packaging" bundle %{pkg_name}-${mod}
 %pom_add_plugin org.apache.felix:maven-bundle-plugin:2.3.7 %{pkg_name}-${mod} '
 <extensions>true</extensions>
 <executions>
   <execution>
     <id>bundle-manifest</id>
     <phase>process-classes</phase>
     <goals>
       <goal>manifest</goal>
     </goals>
   </execution>
 </executions>
 <configuration>
  <excludeDependencies>true</excludeDependencies>
 </configuration>'
done

# No need to package internal build tools
%mvn_package :jctools-build __noinstall

# Fix build against guava 20
rm jctools-core/src/test/java/org/jctools/maps/NonBlockingHashMapTest.java

# Temporary use of bundled javaparser
tar xf %{SOURCE11}
sed -i -e 's/3\.3\.0/3.3.5/' jctools-build/pom.xml
%{?scl:EOFSCL}

%build
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
%mvn_build -s -- -Dguava-testlib.version=20.0 -Dmaven.test.failure.ignore=true
%{?scl:EOFSCL}

%install
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
%mvn_install
%{?scl:EOFSCL}

%files -f .mfiles-%{pkg_name}-core
%doc README.md
%license LICENSE

%files channels -f .mfiles-%{pkg_name}-channels

%files experimental -f .mfiles-%{pkg_name}-experimental

%files javadoc -f .mfiles-javadoc
%license LICENSE

%files parent -f .mfiles-%{pkg_name}-parent
%license LICENSE

%changelog
* Wed Mar 06 2019 Mat Booth <mat.booth@redhat.com> - 2.1.2-1.3
- Ignore intermittent test failure

* Wed Mar 06 2019 Mat Booth <mat.booth@redhat.com> - 2.1.2-1.2
- Fix build against Guava 20
- Fix build against javaparser by temporarily bundling

* Tue Mar 05 2019 Mat Booth <mat.booth@redhat.com> - 2.1.2-1.1
- Auto SCL-ise package for rh-eclipse collection

* Wed Feb 13 2019 Mat Booth <mat.booth@redhat.com> - 2.1.2-1
- Update to latest upstream release

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Sep 17 2017 Mat Booth <mat.booth@redhat.com> - 2.0.2-2
- Drop unneeded dep on guava-testlib

* Mon Aug 14 2017 Tomas Repik <trepik@redhat.com> - 2.0.2-1
- Update to 2.0.2

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Sep 28 2016 gil cattaneo <puntogil@libero.it> 1.2.1-1
- update to 1.2.1

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-0.3.alpha
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-0.2.alpha
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue May 19 2015 gil cattaneo <puntogil@libero.it> 1.1-0.1.alpha
- initial rpm
